@@ -152,15 +152,12 @@ citizen_aqualand_device_dump (dc_device_t *abstract, dc_buffer_t *buffer)
 	dc_status_t status = DC_STATUS_SUCCESS;
 	citizen_aqualand_device_t *device = (citizen_aqualand_device_t *) abstract;
 
-	// Erase the current contents of the buffer and
-	// pre-allocate the required amount of memory.
-	if (!dc_buffer_clear (buffer)) {
-		ERROR (abstract->context, "Insufficient buffer space available.");
-		return DC_STATUS_NOMEMORY;
+	status = dc_iostream_set_dtr (device->iostream, 1);
+	if (status != DC_STATUS_SUCCESS) {
+		ERROR (abstract->context, "Failed to set the DTR line.");
+		return status;
 	}
 
-	dc_iostream_set_dtr (device->iostream, 1);
-
 	// Send the init byte.
 	const unsigned char init[] = {0x7F};
 	status = dc_iostream_write (device->iostream, init, sizeof (init), NULL);
@@ -188,7 +185,10 @@ citizen_aqualand_device_dump (dc_device_t *abstract, dc_buffer_t *buffer)
 			return status;
 		}
 
-		dc_buffer_append(buffer, answer, sizeof (answer));
+		if (!dc_buffer_append(buffer, answer, sizeof (answer))) {
+			ERROR (abstract->context, "Insufficient buffer space available.");
+			return status;
+		}
 
 		// Send the command.
 		status = dc_iostream_write (device->iostream, command, sizeof (command), NULL);
@@ -201,7 +201,11 @@ citizen_aqualand_device_dump (dc_device_t *abstract, dc_buffer_t *buffer)
 			break;
 	}
 
-	dc_iostream_set_dtr (device->iostream, 0);
+	status = dc_iostream_set_dtr (device->iostream, 0);
+	if (status != DC_STATUS_SUCCESS) {
+		ERROR (abstract->context, "Failed to clear the DTR line.");
+		return status;
+	}
 
 	return DC_STATUS_SUCCESS;
 }
