@@ -98,8 +98,9 @@ static const dc_descriptor_t g_descriptors[] = {
 	{"Suunto", "Zoop Novo",  DC_FAMILY_SUUNTO_D9, 0x1E},  // FTDI
 	{"Suunto", "D4f",        DC_FAMILY_SUUNTO_D9, 0x20},  // FTDI
 	/* Suunto EON Steel */
-#ifdef USBHID
+#if defined(USBHID) || defined(ENABLE_BLE)
 	{"Suunto", "EON Steel", DC_FAMILY_SUUNTO_EONSTEEL, 0},  // BLE
+	{"Suunto", "EON Core",  DC_FAMILY_SUUNTO_EONSTEEL, 1},  // BLE
 #endif
 	/* Uwatec Aladin */
 	{"Uwatec", "Aladin Air Twin",     DC_FAMILY_UWATEC_ALADIN, 0x1C},  // FTDI
@@ -138,9 +139,10 @@ static const dc_descriptor_t g_descriptors[] = {
 	{"Scubapro", "Chromis",     DC_FAMILY_UWATEC_MERIDIAN, 0x24},
 	{"Scubapro", "Mantis 2",    DC_FAMILY_UWATEC_MERIDIAN, 0x26},
 	/* Scubapro G2 */
-#ifdef USBHID
-	{"Scubapro", "G2",                  DC_FAMILY_UWATEC_G2, 0x32},  // BLE
+#if defined(USBHID) || defined(ENABLE_BLE)
 	{"Scubapro", "Aladin Sport Matrix", DC_FAMILY_UWATEC_G2, 0x17},  // BLE
+	{"Scubapro", "Aladin Square",       DC_FAMILY_UWATEC_G2, 0x22},
+	{"Scubapro", "G2",                  DC_FAMILY_UWATEC_G2, 0x32},  // BLE
 #endif
 	/* Reefnet */
 	{"Reefnet", "Sensus",       DC_FAMILY_REEFNET_SENSUS, 1},
@@ -248,6 +250,7 @@ static const dc_descriptor_t g_descriptors[] = {
 	{"Mares", "Puck Pro",          DC_FAMILY_MARES_ICONHD , 0x18},
 	{"Mares", "Nemo Wide 2",       DC_FAMILY_MARES_ICONHD , 0x19},
 	{"Mares", "Puck 2",            DC_FAMILY_MARES_ICONHD , 0x1F},
+	{"Mares", "Quad Air",          DC_FAMILY_MARES_ICONHD , 0x23},
 	{"Mares", "Quad",              DC_FAMILY_MARES_ICONHD , 0x29},
 	/* Heinrichs Weikamp */
 	{"Heinrichs Weikamp", "OSTC",     DC_FAMILY_HW_OSTC, 0},  // FTDI
@@ -288,10 +291,11 @@ static const dc_descriptor_t g_descriptors[] = {
 	{"Shearwater", "Predator", DC_FAMILY_SHEARWATER_PREDATOR, 2},  // BT
 	/* Shearwater Petrel family */
 	{"Shearwater", "Petrel",    DC_FAMILY_SHEARWATER_PETREL, 3},  // BT // BLE
-	{"Shearwater", "Petrel 2",  DC_FAMILY_SHEARWATER_PETREL, 4},  // BT // BLE
-	{"Shearwater", "Nerd",      DC_FAMILY_SHEARWATER_PETREL, 5},  // BT
-	{"Shearwater", "Perdix",    DC_FAMILY_SHEARWATER_PETREL, 6},  // BT // BLE
-	{"Shearwater", "Perdix AI", DC_FAMILY_SHEARWATER_PETREL, 7},  // BLE
+	{"Shearwater", "Petrel 2",  DC_FAMILY_SHEARWATER_PETREL, 3},  // BT // BLE
+	{"Shearwater", "Nerd",      DC_FAMILY_SHEARWATER_PETREL, 4},  // BT
+	{"Shearwater", "Perdix",    DC_FAMILY_SHEARWATER_PETREL, 5},  // BT // BLE
+	{"Shearwater", "Perdix AI", DC_FAMILY_SHEARWATER_PETREL, 6},  // BLE
+	{"Shearwater", "Nerd 2",    DC_FAMILY_SHEARWATER_PETREL, 7},  // BLE
 	/* Dive Rite NiTek Q */
 	{"Dive Rite", "NiTek Q",   DC_FAMILY_DIVERITE_NITEKQ, 0},
 	/* Citizen Hyper Aqualand */
@@ -318,6 +322,7 @@ static const dc_descriptor_t g_descriptors[] = {
 	{"Ratio",      "iDive Easy",    DC_FAMILY_DIVESYSTEM_IDIVE, 0x42},
 	{"Ratio",      "iDive Deep",    DC_FAMILY_DIVESYSTEM_IDIVE, 0x44},
 	{"Ratio",      "iDive Tech+",   DC_FAMILY_DIVESYSTEM_IDIVE, 0x45},
+	{"Seac",       "Jack",          DC_FAMILY_DIVESYSTEM_IDIVE, 0x1000},
 	/* Cochran Commander */
 	{"Cochran", "Commander TM", DC_FAMILY_COCHRAN_COMMANDER, 0},  // FTDI
 	{"Cochran", "Commander I",  DC_FAMILY_COCHRAN_COMMANDER, 1},  // FTDI
