@@ -40,7 +40,7 @@
 #define MAXCONFIG 7
 #define NGASMIXES 15
 
-#define UNDEFINED 0xFF
+#define UNDEFINED 0xFFFFFFFF
 
 #define ALL    0
 #define FIXED  1
@@ -65,6 +65,7 @@
 #define OSTC3_CC    1
 #define OSTC3_GAUGE 2
 #define OSTC3_APNEA 3
+#define OSTC3_PSCR  4
 
 #define OSTC3_ZHL16    0
 #define OSTC3_ZHL16_GF 1
@@ -117,6 +118,7 @@ typedef struct hw_ostc_parser_t {
 	unsigned int nfixed;
 	unsigned int initial;
 	unsigned int initial_setpoint;
+	unsigned int initial_cns;
 	hw_ostc_gasmix_t gasmix[NGASMIXES];
 } hw_ostc_parser_t;
 
@@ -259,14 +261,18 @@ hw_ostc_parser_cache (hw_ostc_parser_t *parser)
 	}
 
 	// Get all the gas mixes, the index of the inital mix,
-	// and the initial setpoint (used in the fixed setpoint mode).
+	// the initial setpoint (used in the fixed setpoint CCR mode),
+	// and the initial CNS from the header
 	unsigned int initial = UNDEFINED;
 	unsigned int initial_setpoint = UNDEFINED;
+	unsigned int initial_cns = UNDEFINED;
 	unsigned int ngasmixes = 0;
 	hw_ostc_gasmix_t gasmix[NGASMIXES] = {{0}};
 	if (version == 0x22) {
 		ngasmixes = 3;
-		initial = data[31];
+		if (data[31] != 0xFF) {
+			initial = data[31];
+		}
 		for (unsigned int i = 0; i < ngasmixes; ++i) {
 			gasmix[i].oxygen = data[25 + 2 * i];
 			gasmix[i].helium = 0;
@@ -285,9 +291,13 @@ hw_ostc_parser_cache (hw_ostc_parser_t *parser)
                 if (data[82] == OSTC3_CC) {
 			initial_setpoint = data[60];
 		}
+		// Initial CNS
+		initial_cns = array_uint16_le (data + 53);
 	} else {
 		ngasmixes = 5;
-		initial = data[31];
+		if (data[31] != 0xFF) {
+			initial = data[31];
+		}
 		for (unsigned int i = 0; i < ngasmixes; ++i) {
 			gasmix[i].oxygen = data[19 + 2 * i + 0];
 			gasmix[i].helium = data[19 + 2 * i + 1];
@@ -311,6 +321,7 @@ hw_ostc_parser_cache (hw_ostc_parser_t *parser)
 	parser->nfixed = ngasmixes;
 	parser->initial = initial;
 	parser->initial_setpoint = initial_setpoint;
+	parser->initial_cns = initial_cns;
 	for (unsigned int i = 0; i < ngasmixes; ++i) {
 		parser->gasmix[i] = gasmix[i];
 	}
@@ -345,6 +356,7 @@ hw_ostc_parser_create_internal (dc_parser_t **out, dc_context_t *context, unsign
 	parser->nfixed = 0;
 	parser->initial = 0;
 	parser->initial_setpoint = 0;
+	parser->initial_cns = 0;
 	for (unsigned int i = 0; i < NGASMIXES; ++i) {
 		parser->gasmix[i].oxygen = 0;
 		parser->gasmix[i].helium = 0;
@@ -383,6 +395,7 @@ hw_ostc_parser_set_data (dc_parser_t *abstract, const unsigned char *data, unsig
 	parser->nfixed = 0;
 	parser->initial = 0;
 	parser->initial_setpoint = 0;
+	parser->initial_cns = 0;
 	for (unsigned int i = 0; i < NGASMIXES; ++i) {
 		parser->gasmix[i].oxygen = 0;
 		parser->gasmix[i].helium = 0;
@@ -536,8 +549,10 @@ hw_ostc_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, unsigned
 					break;
 				case OSTC_ZHL16_CC:
 				case OSTC_ZHL16_CC_GF:
+					*((dc_divemode_t *) value) = DC_DIVEMODE_CCR;
+					break;
 				case OSTC_PSCR_GF:
-					*((dc_divemode_t *) value) = DC_DIVEMODE_CC;
+					*((dc_divemode_t *) value) = DC_DIVEMODE_SCR;
 					break;
 				default:
 					return DC_STATUS_DATAFORMAT;
@@ -560,7 +575,7 @@ hw_ostc_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, unsigned
 					*((dc_divemode_t *) value) = DC_DIVEMODE_OC;
 					break;
 				case OSTC3_CC:
-					*((dc_divemode_t *) value) = DC_DIVEMODE_CC;
+					*((dc_divemode_t *) value) = DC_DIVEMODE_CCR;
 					break;
 				case OSTC3_GAUGE:
 					*((dc_divemode_t *) value) = DC_DIVEMODE_GAUGE;
@@ -568,6 +583,9 @@ hw_ostc_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, unsigned
 				case OSTC3_APNEA:
 					*((dc_divemode_t *) value) = DC_DIVEMODE_FREEDIVE;
 					break;
+				case OSTC3_PSCR:
+					*((dc_divemode_t *) value) = DC_DIVEMODE_SCR;
+					break;
 				default:
 					return DC_STATUS_DATAFORMAT;
 				}
@@ -673,6 +691,21 @@ hw_ostc_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callback_t call
 	unsigned int header = parser->header;
 	const hw_ostc_layout_t *layout = parser->layout;
 
+	// Exit if no profile data available.
+	if (size == header || (size == header + 2 &&
+		data[header] == 0xFD && data[header + 1] == 0xFD)) {
+		parser->cached = PROFILE;
+		return DC_STATUS_SUCCESS;
+	}
+
+	// Check the header length.
+	if (version == 0x23 || version == 0x24) {
+		if (size < header + 5) {
+			ERROR (abstract->context, "Buffer overflow detected!");
+			return DC_STATUS_DATAFORMAT;
+		}
+	}
+
 	// Get the sample rate.
 	unsigned int samplerate = 0;
 	if (version == 0x23 || version == 0x24)
@@ -699,6 +732,14 @@ hw_ostc_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callback_t call
 		return DC_STATUS_DATAFORMAT;
 	}
 
+	// Check the header length.
+	if (version == 0x23 || version == 0x24) {
+		if (size < header + 5 + 3 * nconfig) {
+			ERROR (abstract->context, "Buffer overflow detected!");
+			return DC_STATUS_DATAFORMAT;
+		}
+	}
+
 	// Get the extended sample configuration.
 	hw_ostc_sample_info_t info[MAXCONFIG] = {{0}};
 	for (unsigned int i = 0; i < nconfig; ++i) {
@@ -775,6 +816,12 @@ hw_ostc_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callback_t call
 			if (callback) callback (DC_SAMPLE_SETPOINT, sample, userdata);
 		}
 
+		// Initial CNS (%).
+		if (time == samplerate && parser->initial_cns != UNDEFINED) {
+			sample.cns = parser->initial_cns / 100.0;
+			if (callback) callback (DC_SAMPLE_CNS, sample, userdata);
+		}
+
 		// Depth (mbar).
 		unsigned int depth = array_uint16_le (data + offset);
 		sample.depth = (depth * BAR / 1000.0) / hydrostatic;
