@@ -219,9 +219,8 @@ mares_darwin_device_dump (dc_device_t *abstract, dc_buffer_t *buffer)
 
 	assert (device->layout != NULL);
 
-	// Erase the current contents of the buffer and
-	// allocate the required amount of memory.
-	if (!dc_buffer_clear (buffer) || !dc_buffer_resize (buffer, device->layout->memsize)) {
+	// Allocate the required amount of memory.
+	if (!dc_buffer_resize (buffer, device->layout->memsize)) {
 		ERROR (abstract->context, "Insufficient buffer space available.");
 		return DC_STATUS_NOMEMORY;
 	}
@@ -331,7 +330,7 @@ mares_darwin_extract_dives (dc_device_t *abstract, const unsigned char data[], u
 			current -= length;
 		}
 
-		if (device && memcmp (buffer, device->fingerprint, sizeof (device->fingerprint)) == 0) {
+		if (memcmp (buffer, device->fingerprint, sizeof (device->fingerprint)) == 0) {
 			free (buffer);
 			return DC_STATUS_SUCCESS;
 		}
