@@ -30,7 +30,7 @@
 #include "rbstream.h"
 #include "array.h"
 
-#define VTABLE(abstract)	((oceanic_common_device_vtable_t *) abstract->vtable)
+#define VTABLE(abstract)	((const oceanic_common_device_vtable_t *) abstract->vtable)
 
 #define RB_LOGBOOK_DISTANCE(a,b,l)	ringbuffer_distance (a, b, 0, l->rb_logbook_begin, l->rb_logbook_end)
 #define RB_LOGBOOK_INCR(a,b,l)		ringbuffer_increment (a, b, l->rb_logbook_begin, l->rb_logbook_end)
@@ -156,9 +156,8 @@ oceanic_common_device_dump (dc_device_t *abstract, dc_buffer_t *buffer)
 	assert (device != NULL);
 	assert (device->layout != NULL);
 
-	// Erase the current contents of the buffer and
-	// allocate the required amount of memory.
-	if (!dc_buffer_clear (buffer) || !dc_buffer_resize (buffer, device->layout->memsize)) {
+	// Allocate the required amount of memory.
+	if (!dc_buffer_resize (buffer, device->layout->memsize)) {
 		ERROR (abstract->context, "Insufficient buffer space available.");
 		return DC_STATUS_NOMEMORY;
 	}
