@@ -32,7 +32,6 @@
 
 #include "shearwater_predator.h"
 #include "shearwater_petrel.h"
-#include "shearwater_common.h"
 #include "context-private.h"
 #include "parser-private.h"
 #include "array.h"
@@ -57,11 +56,15 @@
 #define NGASMIXES 10
 #define MAXSTRINGS 32
 
+#define PREDATOR 2
+#define PETREL   3
+
 typedef struct shearwater_predator_parser_t shearwater_predator_parser_t;
 
 struct shearwater_predator_parser_t {
 	dc_parser_t base;
 	unsigned int model;
+	unsigned int petrel;
 	unsigned int samplesize;
 	// Cached fields.
 	unsigned int cached;
@@ -71,6 +74,7 @@ struct shearwater_predator_parser_t {
 	unsigned int ngasmixes;
 	unsigned int oxygen[NGASMIXES];
 	unsigned int helium[NGASMIXES];
+	unsigned int calibrated;
 	double calibration[3];
 	unsigned int serial;
 	dc_divemode_t mode;
@@ -119,8 +123,8 @@ shearwater_predator_find_gasmix (shearwater_predator_parser_t *parser, unsigned
 }
 
 
-dc_status_t
-shearwater_common_parser_create (dc_parser_t **out, dc_context_t *context, unsigned int model, unsigned int serial)
+static dc_status_t
+shearwater_common_parser_create (dc_parser_t **out, dc_context_t *context, unsigned int model, unsigned int serial, unsigned int petrel)
 {
 	shearwater_predator_parser_t *parser = NULL;
 	const dc_parser_vtable_t *vtable = NULL;
@@ -129,7 +133,7 @@ shearwater_common_parser_create (dc_parser_t **out, dc_context_t *context, unsig
 	if (out == NULL)
 		return DC_STATUS_INVALIDARGS;
 
-	if (model != PREDATOR) {
+	if (petrel) {
 		vtable = &shearwater_petrel_parser_vtable;
 		samplesize = SZ_SAMPLE_PETREL;
 	} else {
@@ -146,6 +150,7 @@ shearwater_common_parser_create (dc_parser_t **out, dc_context_t *context, unsig
 
 	// Set the default values.
 	parser->model = model;
+	parser->petrel = petrel;
 	parser->samplesize = samplesize;
 	parser->serial = serial;
 
@@ -159,6 +164,10 @@ shearwater_common_parser_create (dc_parser_t **out, dc_context_t *context, unsig
 		parser->oxygen[i] = 0;
 		parser->helium[i] = 0;
 	}
+	parser->calibrated = 0;
+	for (unsigned int i = 0; i < 3; ++i) {
+		parser->calibration[i] = 0.0;
+	}
 	parser->mode = DC_DIVEMODE_OC;
 
 	*out = (dc_parser_t *) parser;
@@ -167,6 +176,20 @@ shearwater_common_parser_create (dc_parser_t **out, dc_context_t *context, unsig
 }
 
 
+dc_status_t
+shearwater_predator_parser_create (dc_parser_t **out, dc_context_t *context, unsigned int model, unsigned int serial)
+{
+	return shearwater_common_parser_create (out, context, model, serial, 0);
+}
+
+
+dc_status_t
+shearwater_petrel_parser_create (dc_parser_t **out, dc_context_t *context, unsigned int model, unsigned int serial)
+{
+	return shearwater_common_parser_create (out, context, model, serial, 1);
+}
+
+
 static dc_status_t
 shearwater_predator_parser_set_data (dc_parser_t *abstract, const unsigned char *data, unsigned int size)
 {
@@ -182,6 +205,10 @@ shearwater_predator_parser_set_data (dc_parser_t *abstract, const unsigned char
 		parser->oxygen[i] = 0;
 		parser->helium[i] = 0;
 	}
+	parser->calibrated = 0;
+	for (unsigned int i = 0; i < 3; ++i) {
+		parser->calibration[i] = 0.0;
+	}
 	parser->mode = DC_DIVEMODE_OC;
 
 	return DC_STATUS_SUCCESS;
@@ -376,7 +403,7 @@ shearwater_predator_parser_cache (shearwater_predator_parser_t *parser)
 	memset(parser->strings, 0, sizeof(parser->strings));
 
 	// Adjust the footersize for the final block.
-	if (parser->model > PREDATOR || array_uint16_be (data + size - footersize) == 0xFFFD) {
+	if (parser->petrel || array_uint16_be (data + size - footersize) == 0xFFFD) {
 		footersize += SZ_BLOCK;
 		if (size < headersize + footersize) {
 			ERROR (abstract->context, "Invalid data length.");
@@ -449,17 +476,34 @@ shearwater_predator_parser_cache (shearwater_predator_parser_t *parser)
 	}
 
 	// Cache sensor calibration for later use
-	parser->calibration[0] = array_uint16_be(data + 87) / 100000.0;
-	parser->calibration[1] = array_uint16_be(data + 89) / 100000.0;
-	parser->calibration[2] = array_uint16_be(data + 91) / 100000.0;
-	// The Predator expects the mV output of the cells to be within 30mV
-	// to 70mV in 100% O2 at 1 atmosphere.
-	// If the calibration value is scaled with a factor 2.2, then the
-	// sensors lines up and matches the average.
-	if (parser->model == PREDATOR) {
-		for (size_t i = 0; i < 3; ++i) {
+	unsigned int nsensors = 0, ndefaults = 0;
+	for (size_t i = 0; i < 3; ++i) {
+		unsigned int calibration = array_uint16_be(data + 87 + i * 2);
+		parser->calibration[i] = calibration / 100000.0;
+		if (parser->model == PREDATOR) {
+			// The Predator expects the mV output of the cells to be
+			// within 30mV to 70mV in 100% O2 at 1 atmosphere. If the
+			// calibration value is scaled with a factor 2.2, then the
+			// sensors lines up and matches the average.
 			parser->calibration[i] *= 2.2;
 		}
+		if (data[86] & (1 << i)) {
+			if (calibration == 2100) {
+				ndefaults++;
+			}
+			nsensors++;
+		}
+	}
+	if (nsensors == ndefaults) {
+		// If all (calibrated) sensors still have their factory default
+		// calibration values (2100), they are probably not calibrated
+		// properly. To avoid returning incorrect ppO2 values to the
+		// application, they are manually disabled (e.g. marked as
+		// uncalibrated).
+		WARNING (abstract->context, "Disabled all O2 sensors due to a default calibration value.");
+		parser->calibrated = 0;
+	} else {
+		parser->calibrated = data[86];
 	}
 
 	// Cache the data for later use.
@@ -630,18 +674,18 @@ shearwater_predator_parser_samples_foreach (dc_parser_t *abstract, dc_sample_cal
 				if (callback) callback (DC_SAMPLE_PPO2, sample, userdata);
 #else
 				sample.ppo2 = data[offset + 12] * parser->calibration[0];
-				if (callback && (data[86] & 0x01)) callback (DC_SAMPLE_PPO2, sample, userdata);
+				if (callback && (parser->calibrated & 0x01)) callback (DC_SAMPLE_PPO2, sample, userdata);
 
 				sample.ppo2 = data[offset + 14] * parser->calibration[1];
-				if (callback && (data[86] & 0x02)) callback (DC_SAMPLE_PPO2, sample, userdata);
+				if (callback && (parser->calibrated & 0x02)) callback (DC_SAMPLE_PPO2, sample, userdata);
 
 				sample.ppo2 = data[offset + 15] * parser->calibration[2];
-				if (callback && (data[86] & 0x04)) callback (DC_SAMPLE_PPO2, sample, userdata);
+				if (callback && (parser->calibrated & 0x04)) callback (DC_SAMPLE_PPO2, sample, userdata);
 #endif
 			}
 
 			// Setpoint
-			if (parser->model > PREDATOR) {
+			if (parser->petrel) {
 				sample.setpoint = data[offset + 18] / 100.0;
 			} else {
 				if (status & SETPOINT_HIGH) {
@@ -654,7 +698,7 @@ shearwater_predator_parser_samples_foreach (dc_parser_t *abstract, dc_sample_cal
 		}
 
 		// CNS
-		if (parser->model > PREDATOR) {
+		if (parser->petrel) {
 			sample.cns = data[offset + 22] / 100.0;
 			if (callback) callback (DC_SAMPLE_CNS, sample, userdata);
 		}
