@@ -46,6 +46,7 @@
 #define GALILEOTRIMIX     0x19
 #define SMARTZ            0x1C
 #define MERIDIAN          0x20
+#define ALADINSQUARE      0x22
 #define CHROMIS           0x24
 #define MANTIS2           0x26
 #define G2                0x32
@@ -522,7 +523,8 @@ uwatec_smart_parser_cache (uwatec_smart_parser_t *parser)
 				if (parser->model == GALILEO || parser->model == GALILEOTRIMIX ||
 					parser->model == ALADIN2G || parser->model == MERIDIAN ||
 					parser->model == CHROMIS || parser->model == MANTIS2 ||
-					parser->model == G2 || parser->model == ALADINSPORTMATRIX) {
+					parser->model == G2 || parser->model == ALADINSPORTMATRIX ||
+					parser->model == ALADINSQUARE) {
 					unsigned int offset = header->tankpressure + 2 * i;
 					endpressure   = array_uint16_le(data + offset);
 					beginpressure = array_uint16_le(data + offset + 2 * header->ngases);
@@ -600,6 +602,7 @@ uwatec_smart_parser_create (dc_parser_t **out, dc_context_t *context, unsigned i
 	case MERIDIAN:
 	case CHROMIS:
 	case MANTIS2:
+	case ALADINSQUARE:
 		parser->headersize = 152;
 		parser->header = &uwatec_smart_galileo_header;
 		parser->samples = uwatec_smart_galileo_samples;
@@ -883,15 +886,15 @@ uwatec_smart_fixsignbit (unsigned int x, unsigned int n)
 		return 0;
 
 	unsigned int signbit = (1 << (n - 1));
-	unsigned int mask = (0xFFFFFFFF << n);
+	unsigned int mask = (signbit - 1);
 
 	// When turning a two's-complement number with a certain number
 	// of bits into one with more bits, the sign bit must be repeated
 	// in all the extra bits.
 	if ((x & signbit) == signbit)
-		return x | mask;
+		return x | ~mask;
 	else
-		return x & ~mask;
+		return x & mask;
 }
 
 
@@ -952,7 +955,8 @@ uwatec_smart_parse (uwatec_smart_parser_t *parser, dc_sample_callback_t callback
 		if (parser->model == GALILEO || parser->model == GALILEOTRIMIX ||
 			parser->model == ALADIN2G || parser->model == MERIDIAN ||
 			parser->model == CHROMIS || parser->model == MANTIS2 ||
-			parser->model == G2 || parser->model == ALADINSPORTMATRIX) {
+			parser->model == G2 || parser->model == ALADINSPORTMATRIX ||
+			parser->model == ALADINSQUARE) {
 			// Uwatec Galileo
 			id = uwatec_galileo_identify (data[offset]);
 		} else {
